@@ -5,7 +5,7 @@ import unittest
 
 from test._utils import printer
 
-from deltalanguage.lib import make_state_saver, make_generator
+from deltalanguage.lib import StateSaver, make_generator
 from deltalanguage.runtime import DeltaPySimulator
 from deltalanguage.wiring import DeltaGraph
 
@@ -16,8 +16,8 @@ class NoMessageTestSimple(unittest.TestCase):
     """
 
     def test_correct_result(self):
-        s1 = make_state_saver(int, condition=lambda x: x % 2 == 0)
-        s2 = make_state_saver(int, condition=lambda x: x == 0)
+        s1 = StateSaver(int, condition=lambda x: x % 2 == 0)
+        s2 = StateSaver(int, condition=lambda x: x == 0)
         l = [1, 3, 7, 2, 5, 4, 9, 0, -1, 8]
         sender = make_generator(l)
 
